==> atlassian-http-0.0.7-sources.jar: com/atlassian/http/mime/ContentDispositionHeaderGuesser.java <==
package com.atlassian.http.mime;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * This class can sniff a file according to the current settings specified by the MimeSNiffPolicyProvider and determine
 * how raw files should be handled.
 */
public class ContentDispositionHeaderGuesser {
    private static final Logger log = LoggerFactory.getLogger(ContentDispositionHeaderGuesser.class);

    private static final String CONTENT_DISPOSITION_ATTACHMENT = "attachment";
    private static final String CONTENT_DISPOSITION_INLINE = "inline";

    private final DownloadPolicyProvider downloadPolicyProvider;
    private final HostileExtensionDetector hostileExtensionDetector;

    public ContentDispositionHeaderGuesser(DownloadPolicyProvider downloadPolicyProvider, HostileExtensionDetector hostileExtensionDetector) {
        this.downloadPolicyProvider = downloadPolicyProvider;
        this.hostileExtensionDetector = hostileExtensionDetector;
    }

    /**
     * This will suggest a content disposition type (inline or attachment) for the given file, respecting the settings
     * given by the provided download policy.
     * <p/>
     * Special treatment is given to html/xml - they will always be displayed inline if the contentType is set to
     * a text type, and if the browser is not IE.
     *
     * @param fileName the name of the file
     * @param mimeContentType the exisiting content type
     * @return either INLINE or ATTACHMENT ready for a Content-Disposition header
     */
    public String guessContentDispositionHeader(String fileName, String mimeContentType, String userAgent) {
        final DownloadPolicy downloadPolicy = downloadPolicyProvider.getPolicy();
        boolean forceDownload = false;
        if (downloadPolicy != DownloadPolicy.Insecure && isExecutableContent(fileName, mimeContentType)) {
            // only in insecure mode we allow direct view of executable content
            forceDownload = true;
            if (log.isDebugEnabled()) {
                log.debug("\"" + fileName + "\" (" + mimeContentType + ")" + " presents as executable content, forcing download.");
            }
        } else if (downloadPolicy == DownloadPolicy.Secure) {
            forceDownload = true;
        }

        //allow inline view for browsers except IE, but only in smart mode
        if (forceDownload
                && isAllowInlineOverride(fileName, mimeContentType, userAgent, downloadPolicy)) {
            forceDownload = false;
        }

        return forceDownload ? CONTENT_DISPOSITION_ATTACHMENT : CONTENT_DISPOSITION_INLINE;
    }

    /**
     * Given a filename, its MIME type, and a browser user agent, return a 'safe' mime type, depending on
     * the download policy configured, such that 'safe' browsers can display the executable text file without causing xss issues.
     * <p/>
     * If the download policy is set to {@link DownloadPolicy#Secure} or {@link DownloadPolicy#Insecure}, then
     * the given mimeContentType will be returned.
     * <p/>
     * If the download policy is set to {@link DownloadPolicy#Smart}, and the user agent is not Internet Explorer
     * , then for text files that can be displayed in  plain text (e.g., text/html, as determined by
     * {@link HostileExtensionDetector#isTextContentType(String)} and {@link HostileExtensionDetector#isTextExtension(String)}),
     * a 'text/plain' mime type will be returned instead of the given mimeContentType.
     *
     * @param filename the file to display
     * @param mimeContentType the mime type for the given file
     * @param userAgent the browser user agent.
     * @return a mime type
     */
    public String guessMIME(String filename, String mimeContentType, String userAgent) {
        if (CONTENT_DISPOSITION_INLINE.equals(guessContentDispositionHeader(filename, mimeContentType, userAgent))
                && isAllowInlineOverride(filename, mimeContentType, userAgent, downloadPolicyProvider.getPolicy())) {
            return "text/plain";
        } else {
            return mimeContentType;
        }
    }

    private boolean isAllowInlineOverride(String fileName, String mimeContentType, String userAgent, DownloadPolicy downloadPolicy) {
        return downloadPolicy == DownloadPolicy.Smart
                && !BrowserUtils.isIE(userAgent)
                && isTextContent(fileName, mimeContentType);
    }

    private boolean isTextContent(String fileName, String mimeContentType) {
        return hostileExtensionDetector.isTextContent(fileName, mimeContentType);
    }

    private boolean isExecutableContent(String name, String mimeContentType) {
        return hostileExtensionDetector.isExecutableContent(name, mimeContentType);
    }
}

==> atlassian-http-1.1.4-sources.jar: com/atlassian/http/mime/ContentDispositionHeaderGuesser.java <==
package com.atlassian.http.mime;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.apache.commons.lang.StringUtils;

/**
 * This class can sniff a file according to the current settings specified by the MimeSNiffPolicyProvider and determine
 * how raw files should be handled.
 */
public class ContentDispositionHeaderGuesser {
    private static final Logger log = LoggerFactory.getLogger(ContentDispositionHeaderGuesser.class);

    private static final String CONTENT_DISPOSITION_ATTACHMENT = "attachment";
    private static final String CONTENT_DISPOSITION_INLINE = "inline";

    private final DownloadPolicyProvider downloadPolicyProvider;
    private final HostileExtensionDetector hostileExtensionDetector;

    public ContentDispositionHeaderGuesser(DownloadPolicyProvider downloadPolicyProvider, HostileExtensionDetector hostileExtensionDetector) {
        this.downloadPolicyProvider = downloadPolicyProvider;
        this.hostileExtensionDetector = hostileExtensionDetector;
    }

    /**
     * This will suggest a content disposition type (inline or attachment) for the given file, respecting the settings
     * given by the provided download policy.
     * <p>
     * Special treatment is given to html/xml - they will always be displayed inline if the contentType is set to
     * a text type, and if the browser is not IE.
     * </p>
     *
     * @param fileName the name of the file
     * @param mimeContentType the existing content type
     * @return either INLINE or ATTACHMENT ready for a Content-Disposition header
     */
    public String guessContentDispositionHeader(String fileName, String mimeContentType, String userAgent) {
        final DownloadPolicy downloadPolicy = downloadPolicyProvider.getPolicy();
        boolean forceDownload = false;

        if (downloadPolicy.equals(DownloadPolicy.Insecure) ) {
            // only in insecure mode we allow direct view of executable content
            return CONTENT_DISPOSITION_INLINE;
        }
        if (downloadPolicy.equals(DownloadPolicy.Secure) ) {
            return CONTENT_DISPOSITION_ATTACHMENT;
        }

        forceDownload = isExecutableContent(fileName, mimeContentType);

        //allow inline view for browsers except IE, but only in smart mode
        if (BrowserUtils.isIE(userAgent) ) {
            /* text/plain is executable in IE */
            if (isTextContentType(mimeContentType)) {
                forceDownload = true;
            }
        }

        if (forceDownload && log.isDebugEnabled() ) {
            log.debug("\"" + fileName + "\" (" + mimeContentType + ")" + " presents as executable content, forcing download.");
        }

        return forceDownload ? CONTENT_DISPOSITION_ATTACHMENT : CONTENT_DISPOSITION_INLINE;
    }

    /**
     * @deprecated since 0.0.8 use {@link ContentDispositionHeaderGuesser#guessMIME(String, boolean)} instead
     * Given a filename, its MIME type, and a browser user agent, return a 'safe' mime type, depending on
     * the download policy configured, such that 'safe' browsers can display the executable text file without causing xss issues.
     * <p>
     * If the download policy is set to {@link DownloadPolicy#Secure} or {@link DownloadPolicy#Insecure}, then
     * the given mimeContentType will be returned.
     * </p><p>
     * If the download policy is set to {@link DownloadPolicy#Smart}, and the user agent is not Internet Explorer
     * , then for text files that can be displayed in  plain text (e.g., text/html, as determined by
     * {@link HostileExtensionDetector#isTextContentType(String)} and {@link HostileExtensionDetector#isTextExtension(String)}),
     * a 'text/plain' mime type will be returned instead of the given mimeContentType.
     * </p>
     *
     * @param filename the file to display
     * @param mimeContentType the mime type for the given file
     * @param userAgent the browser user agent.
     * @return a mime type
     */
    public String guessMIME(String filename, String mimeContentType, String userAgent) {
        if (CONTENT_DISPOSITION_INLINE.equals(guessContentDispositionHeader(filename, mimeContentType, userAgent))
                && isAllowInlineOverride(filename, mimeContentType, userAgent, downloadPolicyProvider.getPolicy())) {
            return "text/plain";
        } else {
            return mimeContentType;
        }
    }

    /**
     * Given a mimeContentType and whether the file is a binary file or not
     * returns text/plain for non-binary files
     * and the given mimeContentType is returned.
     * <p>
     * If the download policy is set to {@link DownloadPolicy#Secure} or {@link DownloadPolicy#Insecure}, then
     * the given mimeContentType will be returned.
     * </p><p>
     *
     * It is recommended to use the 'X-Content-Type-Options' header with a value of 'nosniff'
     * to avoid XSS issues in IE.
     * </p>
     * @param mimeContentType the the mime type for the given file
     * @param isBinaryFile if the file is a binary file or not (true iff binary)
     * @return a mime type
     */
    public String guessMIME(String mimeContentType, boolean isBinaryFile)
    {
        boolean inSmartMode = downloadPolicyProvider.getPolicy().equals(DownloadPolicy.Smart);
        if (!inSmartMode || isBinaryFile)
        {
            return mimeContentType;
        }
        return "text/plain";
    }

    private boolean isAllowInlineOverride(String fileName, String mimeContentType, String userAgent, DownloadPolicy downloadPolicy) {
        return downloadPolicy == DownloadPolicy.Smart
                && !BrowserUtils.isIE(userAgent)
                && isTextContentType(mimeContentType)
                && !StringUtils.isBlank(mimeContentType);
    }

    private boolean isTextContentType(String mimeContentType) {
        return hostileExtensionDetector.isTextContentType(mimeContentType);
    }

    private boolean isExecutableContent(String name, String mimeContentType) {
        return hostileExtensionDetector.isExecutableContent(name, mimeContentType);
    }
}
